OiRA

Help

1. Paruošimas
2. Įtraukti
3. Nustatymas + Vertinimas
4. Veiksmų planas
5. Ataskaita
6. Būsena 0%

# Pritaikyti rizikos vertinimo procedūra pagal savo organizaciją

Norėdami pritaikyti rizikos vertinimo procedūrą pagal savo organizaciją, galite būti paprašyti:

- pasirinkti arba praleisti situacijas, kurios yra susijusios ar nesusijusios su jūsų vykdoma veikla bei pažymėti reikiamus laukelius
- nurodyti padalinius, filialus, parduotuves ar kt. Susijusios rizikos bus kartojamos kiekvienam įvestam pavadinimui.

## Commercial manned guarding

Does your organisation provide commercial manned guarding? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Mobile partrolling/intervention after alarm

Does your organisation provide mobile patrolling / intervention after alarm? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

## Event security

Does your organisation provide event security? Yes No
Do you offer this service in multiple locations? Yes No
Please enter a name for the location you would like to assess. Please enter the name for each location you would like to assess.

Scroll to top
Back

## profiling.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More